Documentation
¶
Overview ¶
This module handles basic configuration of HTTP server. It provides a function for reading environment variables and can set up a logger.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CfgLog ¶
type CfgLog struct {
// contains filtered or unexported fields
}
A configuration struct for the logger, populated from environmental variables.
func (*CfgLog) Config ¶
This method configures logging by reading values from the following environmental variables: - LOG_LEVEL: Minimum log level for emitted messages. Can be any value of slog.Level. - LOG_SOURCE - boolean value - defines if log should contain source code position of the log statement.
type CfgServer ¶
type CfgServer struct {
// contains filtered or unexported fields
}
A configuration struct for the HTTP server, populated from environmental variables.
Click to show internal directories.
Click to hide internal directories.